:warning: Changes marked in bold are possibly breaking. Please, pay special attention to them.

## [1.14.3] - 24.12.2020

- Android Gradle plugin upgraded to 4.1.1
- Minor bug fixes

## [1.14.2] - 11.12.2020

- Improved low-light performance for our liveness detection
- Enhanced security
- Minor bug fixes
- `onActionResult` optional handler added that allows you to handle the action's result upon it's arrival from the backend. The user sees the "Processing..." screen at this moment.
```dart
  final SNSActionResultHandler onActionResult = (SNSMobileSDKActionResult result) {
    print("onActionResult: $result");

    // you must return a `Future` that in turn should be completed with a value of `SNSActionResultHandlerReaction` type
    // you could pass `.Cancel` to force the user interface to close, or `.Continue` to proceed as usual
    return Future.value(SNSActionResultHandlerReaction.Continue);
  };

  final snsMobileSDK = SNSMobileSDK.builder(apiUrl, flowName)
    .withHandlers(
      onActionResult: onActionResult
    )
```

## [1.13.1] - 22.10.2020

- Support for [Face authentication](https://developers.sumsub.com/applicant-actions/#face-authentication) applicant action.
When an action is completed the status will be set to `ActionCompleted` and the result structure would contain the `actionResult` field that describes the outcome of the last invocation. An empty value of `actionResult.answer` means that the action was cancelled.
```dart
SNSMobileSDKResult(
  success: false,
  status: SNSMobileSDKStatus.ActionCompleted,
  actionResult: SNSMobileSDKActionResult(
  	actionId: "{actionId}",
  	answer: SNSMobileSDKAnswerType.Green
  )
)
```

## [1.13.0] - 02.10.2020

- Support for the brand new FaceScan3D module

## [1.12.3] - 22.09.2020

- Upgrade to Kotlin 1.4(Android only)
- Minor bug fixes

## [1.12.2] - 01.09.2020

- Support for Selfie with Document
- Validation for Phone, Email and Date of Birth has been added at the `APPLICANT_DATA` step
- If needed, general moderation comment will be shown when the applicant is rejected
- Support for `<b>` and `<i>` tags within `sns_step_*_prompt` strings
- An omission of the numeric prefix when there is the only step on the initial Status Screen
- Drawing of the `submitted` state when the liveness result is uncertain, but the applicant is allowed to proceed 
- Strings added: `sns_step_SELFIE_photo_title`, `sns_step_SELFIE_photo_brief`, `sns_step_SELFIE_photo_details`, `sns_liveness_check_submitted`
- Some small bugs fixed
- A way to customize iOS part with [the native means](https://developers.sumsub.com/msdk/ios/#customization) by an `IdensicMobileSDKCustomization` class that could be added into the iOS project:
```swift
import Foundation
import IdensicMobileSDK

class IdensicMobileSDKCustomization: NSObject {

  @objc static func apply(_ sdk: SNSMobileSDK) {

    sdk.theme.sns_StatusHeaderTitleColor = .red
  }
}
```

## [1.12.1] - 17.08.2020

- `dismiss()` method added to make SDK dismission easier
- Extended error handling upon uploading fail
- **Added an ability to pick from the gallery** on the `PROOF_OF_RESIDENCE` step

Ensure please to have `NSPhotoLibraryUsageDescription` string in the iOS application's `Info.plist` file
```bash
plutil -insert "NSPhotoLibraryUsageDescription" -string "Let us pick a photo" ios/Runner/Info.plist
```

## [1.12.0] - 31.07.2020

- Support for `APPLICANT_DATA` step
- Ability to force locale with `withLocale` optional method

## [1.11.0] - 07.07.2020

- **[applicant flows](https://test-api.sumsub.com/checkus#/sdkIntegrations/flows) based initialization (`flowName` mandatory parameter added)**
- **Translations are now managed from the [dashboard](https://test-api.sumsub.com/checkus#/sdkIntegrations/globalSettings/msdkI18n)**
- Various security related improvements

## [1.10.1] - 16.06.2020

- Initial release
